## Development TODO notes

An optional priority is indicated by [Pn]

- [P2] Straighten out `TEMP_BASE` and `TEMP_FILE` usages.
- [P3] Add way to convert EX-comments into doctests for use with other tools.
  See https://docs.pytest.org/en/7.1.x/how-to/doctest.html
